@@ -1,9 +1,9 @@
 package WordList;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-05-04'; # DATE
+our $DATE = '2020-05-22'; # DATE
 our $DIST = 'WordList'; # DIST
-our $VERSION = '0.6.0'; # VERSION
+our $VERSION = '0.6.1'; # VERSION
 
 use strict 'subs', 'vars';
 
@@ -75,10 +75,12 @@ sub first_word {
 }
 
 sub pick {
-    my ($self, $n) = @_;
+    my ($self, $n, $allow_duplicates) = @_;
 
     $n = 1 if !defined $n;
     die "Please specify a positive number of words to pick" if $n < 1;
+    die "This implementation of pick() does not produce duplicates"
+        if $allow_duplicates;
 
     if ($n == 1) {
         my $i = 0;
@@ -153,7 +155,7 @@ WordList - Word lists
 
 =head1 VERSION
 
-This document describes version 0.6.0 of WordList (from Perl distribution WordList), released on 2020-05-04.
+This document describes version 0.6.1 of WordList (from Perl distribution WordList), released on 2020-05-22.
 
 =head1 SYNOPSIS
 
@@ -273,10 +275,11 @@ L</next_word>.
 
 Usage:
 
- $wl->pick($n = 1) => list
+ $wl->pick([ $n , [ $allow_duplicates ] ]) => list
 
-Pick C<$n> (default: 1) random word(s) from the list. If there are less then
-C<$n> words in the list, only that many will be returned.
+Pick C<$n> (default: 1) random word(s) from the list, without duplicates (unless
+C<$allow_duplicates> is set to true). If there are less then C<$n> words in the
+list and duplicates are not allowed, only that many will be returned.
 
 The algorithm used is from perlfaq ("perldoc -q "random line""), which scans the
 whole list once (a.k.a. each_word() once). The algorithm is for returning a
